@@ -12,31 +12,33 @@ from . import boundary_conditions
 from . import cli
 from . import config
 from . import datacollector
-from . import em_model
 from . import ep_model
 from . import geometry
-from . import land_model
 from . import mechanics_model
+from . import models
 from . import newton_solver
-from . import ORdmm_Land
 from . import postprocess
+from . import runner
 from . import save_load_functions
-from . import setup_models
 from . import utils
 from .config import Config
 from .config import default_parameters
 from .datacollector import DataCollector
 from .datacollector import DataLoader
-from .em_model import EMCoupling
-from .land_model import LandModel
 from .mechanics_model import MechanicsProblem
 from .mechanics_model import RigidMotionProblem
 from .newton_solver import MechanicsNewtonSolver
 from .newton_solver import MechanicsNewtonSolver_ODE
-from .setup_models import Runner
-from .setup_models import TimeStepper
+from .runner import Runner
+from .runner import TimeStepper
 from .version import __version__
 
+# from . import em_model
+# from . import land_model
+# from . import ORdmm_Land
+# from .em_model import EMCoupling
+# from .land_model import LandModel
+
 
 def set_log_level(level):
     from daiquiri import set_default_log_levels
@@ -47,19 +49,17 @@ def set_log_level(level):
         "simcardems.cli.logger"
         "simcardems.config.logger"
         "simcardems.datacollector.logger"
-        "simcardems.em_model.logger"
         "simcardems.ep_model.logger"
         "simcardems.geometry.logger"
         "simcardems.gui.logger"
-        "simcardems.land_model.logger"
         "simcardems.mechanics_model.logger"
         "simcardems.newton_solver.logger"
         "simcardems.postprocess.logger"
         "simcardems.save_load_functions.logger"
-        "simcardems.setup_models.logger"
+        "simcardems.runner.logger"
         "simcardems.utils.logger"
         "simcardems.value_extractor.logger",
-    ]
+    ] + models.loggers
     _pulse.set_log_level(level)
     _daiquiri.setup(level=level)
 
@@ -96,10 +96,10 @@ _warnings.simplefilter("once", _QuadratureRepresentationDeprecationWarning)
 __all__ = [
     "datacollector",
     "boundary_conditions",
-    "em_model",
+    # "em_model",
     "ep_model",
     "mechanics_model",
-    "ORdmm_Land",
+    # "ORdmm_Land",
     "postprocess",
     "geometry",
     "save_load_functions",
@@ -111,12 +111,12 @@ __all__ = [
     "EMCoupling",
     "DataCollector",
     "DataLoader",
-    "setup_models",
+    "runner",
     "Runner",
     "default_parameters",
     "__version__",
     "TimeStepper",
-    "land_model",
+    # "land_model",
     "newton_solver",
     "MechanicsNewtonSolver_ODE",
     "MechanicsNewtonSolver",
