@@ -4,9 +4,10 @@ from dataclasses import dataclass
 
 import dolfin
 
-from . import land_model
 from . import utils
 
+# from . import land_model
+
 
 @dataclass
 class Config:
@@ -31,7 +32,9 @@ class Config:
     drug_factors_file: utils.PathLike = ""
     popu_factors_file: utils.PathLike = ""
     disease_state: str = "healthy"
-    mechanics_ode_scheme: land_model.Scheme = land_model.Scheme.analytic
+    dt_mech: float = 1.0
+    mechanics_solve_strategy: typing.Literal["fixed", "adaptive"] = "adaptive"
+    # mechanics_ode_scheme: land_model.Scheme = land_model.Scheme.analytic
     ep_ode_scheme: str = "GRL1"
     ep_preconditioner: str = "sor"
     ep_theta: float = 0.5
@@ -39,6 +42,11 @@ class Config:
     mechanics_use_continuation: bool = False
     mechanics_use_custom_newton_solver: bool = False
     PCL: float = 1000
+    coupling_type: typing.Literal[
+        "fully_coupled_ORdmm_Land",
+        "explicit_ORdmm_Land",
+        "pureEP_ORdmm_Land",
+    ] = "fully_coupled_ORdmm_Land"
 
     def as_dict(self):
         return {k: v for k, v in self.__dict__.items()}
