@@ -1,7 +1,11 @@
+from __future__ import annotations
+
 import json
 from pathlib import Path
 from typing import Dict
 from typing import Optional
+from typing import Type
+from typing import TYPE_CHECKING
 
 import cbcbeat
 import dolfin
@@ -9,11 +13,75 @@ import pulse
 import ufl
 
 from . import utils
-from .ORdmm_Land import ORdmm_Land as CellModel
+from .config import Config
+
+if TYPE_CHECKING:
+    from .models.em_model import BaseEMCoupling
+
+# from .ORdmm_Land import ORdmm_Land as CellModel
 
 logger = utils.getLogger(__name__)
 
 
+def setup_cell_model(
+    cls,
+    coupling: BaseEMCoupling,
+    cell_params=None,
+    cell_inits=None,
+    cell_init_file=None,
+    drug_factors_file=None,
+    popu_factors_file=None,
+    disease_state=Config.disease_state,
+):
+    cell_params = handle_cell_params(
+        cell_params=cell_params,
+        disease_state=disease_state,
+        drug_factors_file=drug_factors_file,
+        popu_factors_file=popu_factors_file,
+        CellModel=cls,
+    )
+
+    cell_inits = handle_cell_inits(
+        cell_inits=cell_inits,
+        cell_init_file=cell_init_file,
+        CellModel=cls,
+    )
+
+    return cls(
+        init_conditions=cell_inits,
+        params=cell_params,
+        coupling=coupling,
+    )
+
+
+def setup_solver(
+    dt,
+    cellmodel: cbcbeat.CardiacCellModel,
+    coupling: BaseEMCoupling,
+    scheme=Config.ep_ode_scheme,
+    theta=Config.ep_theta,
+    preconditioner=Config.ep_preconditioner,
+    PCL=Config.PCL,
+) -> cbcbeat.SplittingSolver:
+
+    # Set-up cardiac model
+    ps = setup_splitting_solver_parameters(
+        theta=theta,
+        preconditioner=preconditioner,
+        dt=dt,
+        scheme=scheme,
+    )
+    ep_heart = setup_model(cellmodel, coupling.geometry.ep_mesh, PCL=PCL)
+    solver = cbcbeat.SplittingSolver(ep_heart, params=ps)
+    # Extract the solution fields and set the initial conditions
+    (vs_, vs, vur) = solver.solution_fields()
+    vs_.assign(cellmodel.initial_conditions())
+
+    coupling.register_ep_model(solver)
+    coupling.print_ep_info()
+    return solver
+
+
 def default_conductivities():
     # Conductivities as defined by page 4339 of Niederer benchmark
     return dict(
@@ -75,7 +143,7 @@ def default_microstructure():
     )
 
 
-def setup_ep_model(
+def setup_model(
     cellmodel,
     mesh,
     PCL=1000,
@@ -194,6 +262,7 @@ def load_json(filename: str):
 
 
 def handle_cell_params(
+    CellModel: Type[cbcbeat.CardiacCellModel],
     cell_params: Optional[Dict[str, float]] = None,
     disease_state: str = "healthy",
     drug_factors_file: str = "",
@@ -225,6 +294,7 @@ def handle_cell_params(
 
 
 def handle_cell_inits(
+    CellModel: Type[cbcbeat.CardiacCellModel],
     cell_inits: Optional[Dict[str, float]] = None,
     cell_init_file: str = "",
 ) -> Dict[str, float]:
@@ -236,7 +306,10 @@ def handle_cell_inits(
         cell_inits_tmp.update(load_json(cell_init_file))
         from .save_load_functions import load_initial_conditions_from_h5
 
-        cell_inits = load_initial_conditions_from_h5(cell_init_file)
+        cell_inits = load_initial_conditions_from_h5(
+            cell_init_file,
+            CellModel=CellModel,
+        )
 
     # FIXME: This is a bit confusing, since it will overwrite the
     # inputs from the cell_init_file. There should be only one way to
