@@ -12,6 +12,7 @@ import pulse
 from cardiac_geometries.geometry import Geometry
 from cardiac_geometries.geometry import H5Path
 from cardiac_geometries.geometry import MeshTypes
+from mpi4py import MPI
 
 from . import utils
 
@@ -126,6 +127,9 @@ class BaseGeometry(abc.ABC):
         # TODO: We might add more checks here
         return self.parameters == __o.parameters
 
+    def comm(self) -> MPI.Comm:
+        return self.mesh.mpi_comm()
+
     def validate(self):
         pass
 
@@ -218,8 +222,13 @@ class BaseGeometry(abc.ABC):
     def _default_mesh(self) -> dolfin.Mesh:
         ...
 
+    @property
+    def facet_normal(self) -> dolfin.FacetNormal:
+        return dolfin.FacetNormal(self.mesh)
+
     @property
     def mesh(self) -> dolfin.Mesh:
+        # FIXME: This should be optional
         return self.mechanics_mesh
 
     @property
